#
# spec file
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2015 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor qt6%{nil}
%if "%{flavor}" == ""
ExclusiveArch:  do_not_build
%endif
%if "%{flavor}" == "qt5"
  %define qt5 1
  %define qt_min_version 5.15.2
  %define _plugindir %{_libqt5_plugindir}
  %define _suffix %{nil}
%endif
%if "%{flavor}" == "qt6"
  %define qt6 1
  %define qt_min_version 6.2.0
  %define _plugindir %{_qt6_pluginsdir}
  %define _suffix 6
%endif
%define sover 1
Name:           adwaita-qt%{?_suffix}%{?_suffix:-src}
Version:        1.4.2
Release:        150500.1.2
Summary:        Adwaita theme for Qt-based applications
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://github.com/FedoraQt/adwaita-qt
Source0:        %{url}/archive/%{version}/adwaita-qt-%{version}.tar.gz
BuildRequires:  cmake >= 3.17
BuildRequires:  fdupes
BuildRequires:  pkgconfig
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150400
BuildRequires:  extra-cmake-modules
%else
BuildRequires:  gcc-c++
%endif
%if 0%{?qt5}
BuildRequires:  cmake(Qt5Core) >= %{qt_min_version}
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  pkgconfig(xcb) >= 1.10
Requires:       adwaita-%{flavor}
Obsoletes:      adwaita-qt4 < 1.2.0
%endif
%if 0%{?qt6}
BuildRequires:  cmake(Qt6Core) >= %{qt_min_version}
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Widgets)
Requires:       adwaita-%{flavor}
%endif

%description
Theme to let Qt applications fit nicely into GNOME desktop.

%package -n adwaita-%{flavor}
Requires:       libadwaita%{flavor}-%{sover} = %{version}-%{release}
%if 0%{?qt5}
Summary:        Adwaita Qt5 theme
%endif
%if 0%{?qt6}
Summary:        Adwaita Qt6 theme
%endif
%if 0%{?qt5}
Supplements:    (libQt5Core5 and gnome-session)
%endif
%if 0%{?qt6}
Supplements:    (libQt6Core6 and gnome-session)
%endif

%description -n adwaita-%{flavor}
%if 0%{?qt5}
Adwaita theme variant for applications utilizing Qt5
%endif
%if 0%{?qt6}
Adwaita theme variant for applications utilizing Qt6
%endif

%package -n libadwaita%{flavor}-%{sover}
%if 0%{?qt5}
Summary:        Adwaita Qt5 library
# The package was wwronlgy called  libadwaitaqt1_2_0 in the past
# As long as we are at .so.1, we can obsolete this old, wrong
# package name
Obsoletes:      libadwaitaqt1_2_0
Obsoletes:      libadwaitaqt%{sover} <= 1.4.0
Provides:       libadwaitaqt%{sover} = %{version}
%endif
%if 0%{?qt6}
Summary:        Adwaita Qt6 library
%endif

%description -n libadwaita%{flavor}-%{sover}
%if 0%{?qt5}
Adwaita theme variant for applications utilizing Qt5
%endif
%if 0%{?qt6}
Adwaita theme variant for applications utilizing Qt6
%endif

%package -n libadwaita-%{flavor}-devel
Summary:        Development files for libadwaita-%{flavor}
Requires:       libadwaita%{flavor}-%{sover} = %{version}
%if 0%{?qt5}
Obsoletes:      libadwaitaqt-devel <= 1.4.0
Provides:       libadwaitaqt-devel = %{version}
%endif
%if 0%{?qt6}
Requires:       cmake(Qt6Core)
Requires:       cmake(Qt6Widgets)
%endif

%description -n libadwaita-%{flavor}-devel
The libadwaita-%{flavor}-devel package contains libraries and header files for
developing applications that use libadwaita-%{flavor}-%{sover}.

%prep
%autosetup -p1 -n adwaita-qt-%{version}

%build

%if 0%{?qt5}
%cmake \
  -DUSE_QT6=false \
%endif
%if 0%{?qt6}
%cmake_qt6 \
  -DUSE_QT6=true \
%endif

%if 0%{?qt6}
%{qt6_build}
%else
%cmake_build
%endif

%install

%if 0%{?qt6}
%{qt6_install}
%else
%cmake_install
%endif

# qt6 does not have a pc file, so the generated pc we have is invalid, nuke it.
rm -rf %{buildroot}%{_libdir}/pkgconfig/adwaita-qt6.pc

%ldconfig_scriptlets -n libadwaita%{flavor}-%{sover}

%files -n adwaita-%{flavor}
%license LICENSE.LGPL2
%doc README.md
%dir %{_plugindir}/styles
%{_plugindir}/styles/adwaita.so

%files -n libadwaita%{flavor}-%{sover}
%{_libdir}/libadwaitaqt%{_suffix}.so.*
%{_libdir}/libadwaitaqt%{_suffix}priv.so.*

%files -n libadwaita-%{flavor}-devel
%dir %{_includedir}/AdwaitaQt%{_suffix}
%{_includedir}/AdwaitaQt%{_suffix}/*.h
%dir %{_libdir}/cmake/AdwaitaQt%{_suffix}
%{_libdir}/cmake/AdwaitaQt%{_suffix}/*.cmake
%if 0%{?qt5}
%{_libdir}/pkgconfig/adwaita-qt%{_suffix}.pc
%endif
%{_libdir}/libadwaitaqt%{_suffix}.so
%{_libdir}/libadwaitaqt%{_suffix}priv.so

%changelog
* Thu Mar  2 2023 alarrosa@suse.com
- Use the qt6 %%cmake macros when building the qt6 flavor which
  uses the right compiler in SLE/Leap instead of gcc7 (which fails
  to build since it doesn't support C++17 headers used by Qt6).
* Tue Sep 27 2022 luc14n0@opensuse.org
- Update to version 1.4.2:
  + Fixed plugin path for Qt6.
  + Switch between dark/light variant on runtime on
    QEvent::PaletteChange.
  + Qt5X11Extras is an optional dependency.
  + UI: QMenu improvements.
  + Fixed placeholder text color for Qt6.
* Thu Feb 24 2022 bjorn.lie@gmail.com
- Add hard cmake(Qt6Core) and cmake(Qt6Widgets) Requires to
  libadwaita-qt6-devel sub-package.
- Nuke the generated .pc file from the same sub-package, it is
  invalid.
- Use ldconfig_scriptlets macro for post(un) handling.
* Wed Feb 23 2022 bjorn.lie@gmail.com
- Drop baselibs.conf: Stop supporting 32bit on x86_64, the only
  known consumer have dropped it also.
* Wed Nov 10 2021 idesmi@protonmail.com
- Update to version 1.4.1
  * Support for Qt6 build with CMake option -DUSE_QT6=true.
  * QProgressBar: correctly get information whether we should
    render horizontal or vertical bar.
- Convert to _multibuild: enable builds for Qt5 and Qt6.
* Tue Oct 19 2021 rpm@fthiessen.de
- Update to version 1.4.0
  + Base colors are now parsed from stylesheets provided by GTK 4
  + Added variants for HighContrast and HighContrastInverse
* Wed Jun  9 2021 dimstar@opensuse.org
- Update to version 1.3.1:
  + Fixed wrongly advertised version.
  + Fixed compatibility with older versions.
  + Fixed QTabWidget issue where tabs were stretched to full
    width/heigh.
* Sun May 23 2021 rpm@fthiessen.de
- Update to 1.3.0
  * Adwaita-qt library now provides Adwaita::Renderer class to
    render Adwaita components
  * Minor bug fixes
* Fri May 21 2021 dimstar@opensuse.org
- Add baselibs.conf: create libadwaitaqt1-32bit as needed by
  QGNomePlatform.
* Thu Apr 15 2021 dimstar@opensuse.org
- Fix SLPP package name:
  + Rename libadwaitaqt1_2_1 to  libadwaitaqt1: the libraries have
    a sover of '1'.
  + Obsolete the previously wrongly named  libadwaitaqt1_2_0 (
    libadwaitaqt1_2_1 was never shipped in a product).
* Tue Apr 13 2021 rpm@fthiessen.de
- Update to 1.2.1
  * Fixes for Adwaita library
  * Define ADWAITAQT_LIBRARIES variable
  * Define ADWAITAQT_INCLUDE_DIRS variable
* Tue Jan  5 2021 elimat@opensuse.org
- Update to 1.2.0
  * Adwaita-qt now provides a library providing Adwaita specific colors
  * Checkbox: removed space before indicator for better consistency with other widgets
  * Qt4 version is no longer supported
  * Adwaita-qt can be successfuly build on Windows and Mac OS
- Stop building qt4 version since support for it have been dropped
- add devel package and shared library package for qt5
- Require adwaita-qt5 and obsolete adwaita-qt4 for older versions
* Wed Jul 29 2020 elimat@opensuse.org
- Update to 1.1.4
  * Do not set color to views which don't use our palette
- Update to 1.1.3
  * Fix crash when accessing already deleted widget (qutebrowser/qutebrowser#5435)
- Update to 1.1.2
  * Correctly set Light, Midlight, Mid and Dark colors
  * Specify XCB types correctly to avoid crash on 32-bit systems
  * QMenu: allow icons
  * QMenu: move text in submenus to avoid having arrow ipainted over accelerator
  * QTreeView: don't use different colors for unfocused views
  * QCheckBox/QRadioButton: update colors to match latest adwaita changes
  * Implement standardPalette() which might be used by some applications
- Run spec-cleaner
* Mon Feb  3 2020 stasiek@michalski.cc
- Update to 1.1.1
  * Stability fixes
- Remove patch:
  * adwaita-qt-upstream-fixes.patch
* Fri Oct  4 2019 bjorn.lie@gmail.com
- Add adwaita-qt-upstream-fixes.patch: Pull in latest fixes from
  upstream.
* Fri Aug  2 2019 alarrosa@suse.com
- Update to 1.1.0:
  * support for the new refreshed Adwaita theme
- Update to 1.0.91:
  * removed alternating rows in views
  * removed frame in locked dock widget
  * fixed build against qt4
  * fixed view items not appearing in qt4 apps
  * fixed scrollbar colors
  * fixed menu item accelerator color
  * fixed menu item separator color and height
- Update to 1.0.90:
  * support for the new refreshed Adwaita theme
* Wed Apr 17 2019 dimstar@opensuse.org
- Only build the -Qt4 variant up to suse_version 1500.
* Thu Feb 22 2018 fcrozat@suse.com
- Do not build with Qt4 on SLE15.
- Use the new license tag for license files.
* Fri Aug 11 2017 fcrozat@suse.com
- Update to version 1.0 (no changelog but only theming
  improvements).
- common subpackage no longer exists.
* Tue Mar  8 2016 tchvatal@suse.com
- Fix license
- Remove pointless requires
* Mon Mar  7 2016 tchvatal@suse.com
- Add supplements to libqt{4,5} and gnome-session
* Mon Mar  7 2016 tchvatal@suse.com
- Tweak a bit so it builds for me
* Thu Jul 30 2015 zaitor@opensuse.org
- Initial build.
